summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/tests/mock/kopeteprotocol_mock.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/tests/mock/kopeteprotocol_mock.cpp')
-rw-r--r--kopete/libkopete/tests/mock/kopeteprotocol_mock.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kopete/libkopete/tests/mock/kopeteprotocol_mock.cpp b/kopete/libkopete/tests/mock/kopeteprotocol_mock.cpp
index d9ae1d3a..03a65808 100644
--- a/kopete/libkopete/tests/mock/kopeteprotocol_mock.cpp
+++ b/kopete/libkopete/tests/mock/kopeteprotocol_mock.cpp
@@ -1,5 +1,5 @@
/*
- Protocol mock object class
+ Protocol tqmock object class
Copyright (c) 2005 by Duncan Mac-Vicar Prett <duncan@kde.org>
@@ -15,7 +15,7 @@
*************************************************************************
*/
-#include "kopeteprotocol_mock.h"
+#include "kopeteprotocol_tqmock.h"
namespace Kopete
{
@@ -24,7 +24,7 @@ namespace Test
namespace Mock
{
-Protocol::Protocol( KInstance *instance, TQObject *parent, const char *name ) : Kopete::Protocol(instance, parent, name)
+Protocol::Protocol( KInstance *instance, TQObject *tqparent, const char *name ) : Kopete::Protocol(instance, tqparent, name)
{
}
@@ -34,16 +34,16 @@ Account* Protocol::createNewAccount( const TQString &accountId )
return 0L;
}
-AddContactPage* Protocol::createAddContactWidget( TQWidget *parent, Kopete::Account *account )
+AddContactPage* Protocol::createAddContactWidget( TQWidget *tqparent, Kopete::Account *account )
{
return 0L;
}
-KopeteEditAccountWidget* Protocol::createEditAccountWidget( Kopete::Account *account, TQWidget *parent )
+KopeteEditAccountWidget* Protocol::createEditAccountWidget( Kopete::Account *account, TQWidget *tqparent )
{
return 0L;
}
-} // end ns mock
+} // end ns tqmock
} // end ns test
} // end ns kopete